==> portal-contribuinte-3.310.0.zip: BOOT-INF/classes/br/com/elotech/tributos/calculo/repository/load-cadastro-imobiliario-memoria.sql <==
select cadastrogeral.idkey as ci_tribcadastrogeral_idkey,
       cadastroimobiliario.tipocadastro as ci_tipocadastro,
       cadastroimobiliario.cadastrogeral as ci_cadastrogeral,
       cadastroimobiliario.inscricaocadastral as ci_inscricaocadastral,
       cadastroimobiliario.inscricaocadastralanterior as ci_inscricaocadastralanterior,
       cadastroimobiliario.quadra_inscricaocadastral as ci_quadra_inscricaocadastral,
       cadastroimobiliario.lote_inscricaocadastral as ci_lote_inscricaocadastral,
       cadastroimobiliario.distrito_inscricaocadastral as ci_distrito_inscricaocadastral,
       cadastroimobiliario.setor_inscricaocadastral as ci_setor_inscricaocadastral,
       cadastroimobiliario.unidade_inscricaocadastral as ci_unidade_inscricaocadastral,
       cadastroimobiliario.distrito_descr as ci_distrito_descr,
       cadastroimobiliario.setor_descr as ci_setor_descr,
       cadastroimobiliario.quadra_descr as ci_quadra_descr,
       cadastroimobiliario.lote_descr as ci_lote_descr,
       cadastroimobiliario.unidade_descr as ci_unidade_descr,
       cadastroimobiliario.imobiliaria as ci_imobiliaria,
       cadastroimobiliario.condominio as ci_condominio,
       cadastroimobiliario.loteamento as ci_loteamento,
       cadastroimobiliario.arealote as ci_arealote,
       cadastroimobiliario.profundidademedia as ci_profundidademedia,
       cadastroimobiliario.areatotalconstruida as ci_areatotalconstruida,
       cadastroimobiliario.matricula as ci_matricula,
       cadastroimobiliario.cartorio as ci_cartorio,
       cadastroimobiliario.datamatricula as ci_datamatricula,
       cadastroimobiliario.facequadra as ci_facequadra,
       cadastroimobiliario.areaunidadeconstruida as ci_areaunidadeconstruida,
       cadastroimobiliario.areautillote as ci_areautillote,
       cadastroimobiliario.areaprivativa as ci_areaprivativa,
       cadastroimobiliario.areacomum as ci_areacomum,
       cadastroimobiliario.complementolote as ci_complementolote,
       cadastroimobiliario.tipoimovel as ci_tipoimovel,
       cadastroimobiliario.tipolote as ci_tipolote,
       cadastroimobiliario.quadricula_inscricaocadastral as ci_quadricula_inscricao,
       cadastroimobiliario.numeroincra as ci_numeroincra,
       cadastroimobiliario.situacaodesapropriado as ci_situacaodesapropriado,
       cadastroimobiliario.quadricula_descri as ci_quadricula_descri,
       cadastroimobiliario.areatotalinscricao as ci_areatotalinscricao,
       cadastrogeral.pessoa                     as cg_pessoa                     ,
       cadastrogeral.logradouro                 as cg_logradouro                 ,
       cadastrogeral.numero                     as cg_numero                     ,
       cadastrogeral.englobado                  as cg_englobado                  ,
       cadastrogeral.complemento                as cg_complemento                ,
       cadastrogeral.suspensoemissao            as cg_suspensoemissao            ,
       cadastrogeral.cidade                     as cg_cidade                     ,
       cadastrogeral.bairro                     as cg_bairro                     ,
       cadastrogeral.correspondencialocal       as cg_correspondencialocal       ,
       cadastrogeral.datainclusao               as cg_datainclusao               ,
       cadastrogeral.dataalteracao              as cg_dataalteracao              ,
       cadastrogeral.cep                        as cg_cep                        ,
       cg.tipocadastroanterior       as cg_tipocadastroanterior       ,
       cg.cadastrogeralanterior      as cg_cadastrogeralanterior      ,
       cadastrogeral.enderecocorrespondencia    as cg_enderecocorrespondencia    ,
       cadastrogeral.numerocorrespondencia      as cg_numerocorrespondencia      ,
       cadastrogeral.complementocorrespondencia as cg_complementocorrespondencia ,
       cadastrogeral.cidadeufcorrespondencia    as cg_cidadeufcorrespondencia    ,
       cadastrogeral.cepcorrespondencia         as cg_cepcorrespondencia         ,
       cadastrogeral.bairrocorrespondencia      as cg_bairrocorrespondencia      ,
       cadastrogeral.enderecoentregacarneanual  as cg_enderecoentregacarneanual  ,
       cadastrogeral.ufcorrespondencia          as cg_ufcorrespondencia          ,
       (select case when count(1) > 0
                        then 1
                    else 0
                   end
        from tribimobiliariocaucao caucao
         left join tribimobiliariocaucao caucaoimob
           on caucaoimob.entidade = caucao.entidade
           and caucaoimob.caucao = caucao.caucao
        where caucao.tipocadastro = cadastroimobiliario.tipocadastro
          and caucao.cadastrogeral = cadastroimobiliario.cadastrogeral
          and caucaoimob.liberado = 'S') as sit_existecaucao,
       segmento.idkey as seg_id,
       segmento.sequencia as seg_sequencia,
       segmento.tiposegmento as seg_tiposegmento,
       segmento.areaconstruida as seg_areaconstruida,
       segmento.principal as seg_principal,
       segmento.areacoberta as seg_areacoberta,
       segmento.areadescoberta as seg_areadescoberta,
       segmento.idsegmentoimobiliario as seg_idsegmentoimobiliario,
       situacaoSegmento.idsituacaoSegmento as sitseg_idsituacaosegmento,
       situacaoSegmento.lancaimposto as sitseg_lancaimposto,
       situacaoSegmento.situacaoregular as sitseg_situacaoregular,
       tiposegmento.descricao as tiposeg_descricao,
       logradourotestada.idlogradourotestada     as lt_idlogradourotestada ,
       logradourotestada.distrito                as lt_distrito,
       logradourotestada.setor                   as lt_setor,
       logradourotestada.cidade                  as lt_cidade,
       logradourotestada.logradouro              as lt_logradouro,
       logradourotestada.quadra                  as lt_quadra,
       logradourotestada.facequadra              as lt_facequadra,
       logradourotestada.lado                    as lt_lado,
       logradourotestada.quadraoposta            as lt_quadraoposta,
       logradourotestada.quadricula              as lt_quadricula,
       logradourotestadaexercicio.exercicio           as lte_exercicio           ,
       logradourotestadaexercicio.largurarua          as lte_largurarua          ,
       logradourotestadaexercicio.valorterreno        as lte_valorterreno        ,
       logradourotestadaexercicio.valorterrenoitbi    as lte_valorterrenoitbi    ,
       logradourotestadaexercicio.valorterrenooutro   as lte_valorterrenooutro   ,
       (select count(1)
       from tribimobiliariosegmento seg
       left join TRIBSITUACAOSEGMENTOIMOB sit
              on seg.idsituacaosegmento = sit.idsituacaosegmento
       where seg.tipocadastro = cadastroimobiliario.tipocadastro
         and seg.cadastrogeral = cadastroimobiliario.cadastrogeral
         and coalesce(sit.lancaimposto, 'S') = 'S') as quantidadeConstrucoes,
       logradourotestada.idlogradourotestada,
       imobiliariotestadagenerica.id as itg_codigotestadagenerica,
       imobiliariotestadagenerica.cidade as itg_cidade,
       imobiliariotestadagenerica.logradouro as itg_logradouro,
       imobiliariotestadagenerica.tamanho as itg_tamanho,
       coalesce(imobiliariotestadagenerica.profundidade ,0) as itg_profundidade,
       imobiliariotestadagenerica.face as itg_face,
       coalesce(imobiliariotestadagenerica.valorm2,0) as itg_valorm2,
       imobiliariotestadagenerica.numero as itg_numero,
       tribsituacaoimobiliario.situacaoimobiliario as sit_situacaoimobiliario,
       tribsituacaoimobiliario.tiposituacaoimobiliario as sit_tiposituacaoimobiliario,
       coalesce(imobiliariotestada.tamanhotestada, 0) as it_testadaprincipal,
       coalesce((
                select sum(TribImobiliarioTestada.tamanhotestada)
                from tribimobiliariotestadamemoria TribImobiliarioTestada
                where TribImobiliarioTestada.cadastrogeral = cadastroimobiliario.cadastrogeral), 0) as it_somatestada,
       coalesce((
                select sum(lte.valorterreno)/count(it.*)
                from tribimobiliariotestadamemoria it
               	join triblogradourotestada lt on lt.idlogradourotestada = it.idlogradourotestada
               	join tribtestadaexerciciomemoria lte
               	  on lte.idlogradourotestada = lt.idlogradourotestada
               	 and lte.idmemoriacadastro = it.idmemoriacadastro
                where it.tipocadastro = cadastrogeral.tipocadastro
                and it.cadastrogeral = cadastrogeral.cadastrogeral
                and it.idmemoriacadastro = cadastrogeral.idmemoriacadastro
                and lte.exercicio = extract(year from now())
                and it.utilizaparacalculo  = 'S'), 0) as it_mediavalortestadas,
       coalesce((
                select sum(area)
                from tribimobiliarioareaverdemem tribimobiliarioareaverde
                where tribimobiliarioareaverde.tipocadastro = cadastrogeral.tipocadastro
                  and tribimobiliarioareaverde.cadastrogeral = cadastrogeral.cadastrogeral
                  and tribimobiliarioareaverde.idmemoriacadastro = cadastrogeral.idmemoriacadastro
                  and tribimobiliarioareaverde.consideraparacalculo = 'S'), 0) as av_area
  from tribcadastroimobiliariomemoria cadastroimobiliario
  join tribcadastrogeral cg
     on cg.cadastrogeral = cadastroimobiliario.cadastrogeral
    and cg.tipocadastro = cadastroimobiliario.tipocadastro
  join tribcadastrogeralmemoria cadastrogeral
     on cadastrogeral.cadastrogeral = cadastroimobiliario.cadastrogeral
    and cadastrogeral.tipocadastro = cadastroimobiliario.tipocadastro
    and cadastrogeral.idmemoriacadastro = cadastroimobiliario.idmemoriacadastro
  left join tribimobiliariosegmentomemoria segmento
    on cadastroimobiliario.tipocadastro = segmento.tipocadastro
   and cadastroimobiliario.cadastrogeral = segmento.cadastrogeral
   and cadastroimobiliario.idmemoriacadastro = segmento.idmemoriacadastro
  left join tribtiposegmento tiposegmento
    on segmento.tiposegmento = tiposegmento.tiposegmento
  left join TRIBSITUACAOSEGMENTOIMOB situacaoSegmento
    on segmento.idsituacaosegmento = situacaoSegmento.idsituacaosegmento
  left join tribimobiliariotestadamemoria imobiliariotestada
     on cadastroimobiliario.cadastrogeral = imobiliariotestada.cadastrogeral
    and cadastroimobiliario.tipocadastro = imobiliariotestada.tipocadastro
    and imobiliariotestada.principal = 'S'
  left join triblogradourotestada logradourotestada
    on imobiliariotestada.idlogradourotestada = logradourotestada.idlogradourotestada
   and logradourotestada.exclusaologica = 'N'
  left join tribtestadaexerciciomemoria logradourotestadaexercicio
    on logradourotestadaexercicio.idlogradourotestada = logradourotestada.idlogradourotestada
   and logradourotestadaexercicio.idmemoriacadastro = cadastroimobiliario.idmemoriacadastro
   and logradourotestadaexercicio.exercicio = :exercicio
   and logradourotestadaexercicio.principal = 'S'
  left join tribimobiliariotestadagenmem imobiliariotestadagenerica
    on cadastroimobiliario.tipocadastro = imobiliariotestadagenerica.tipocadastro
   and cadastroimobiliario.cadastrogeral = imobiliariotestadagenerica.cadastrogeral
   and cadastroimobiliario.idmemoriacadastro = imobiliariotestadagenerica.idmemoriacadastro
   and imobiliariotestadagenerica.principal = 'S'
  left join tribimobiliariosituacaomem tribimobiliariosituacao
    on tribimobiliariosituacao.tipocadastro = cadastroimobiliario.tipocadastro
   and tribimobiliariosituacao.cadastrogeral = cadastroimobiliario.cadastrogeral
   and tribimobiliariosituacao.idmemoriacadastro = imobiliariotestadagenerica.idmemoriacadastro
   and tribimobiliariosituacao.atual = 'S'
  left join tribsituacaoimobiliario tribsituacaoimobiliario
       on tribsituacaoimobiliario.situacaoimobiliario = tribimobiliariosituacao.situacaoimobiliario
 where cadastrogeral.exclusaologica = 'N'
 and  (coalesce(situacaoSegmento.lancaimposto, 'S') = 'S' OR (cadastroimobiliario.tipoimovel = 'T'))
 and %s

==> portal-contribuinte-3.326.0.zip: BOOT-INF/classes/br/com/elotech/tributos/calculo/repository/load-cadastro-imobiliario-memoria.sql <==
select cadastrogeral.idkey as ci_tribcadastrogeral_idkey,
       cadastroimobiliario.tipocadastro as ci_tipocadastro,
       cadastroimobiliario.cadastrogeral as ci_cadastrogeral,
       cadastroimobiliario.inscricaocadastral as ci_inscricaocadastral,
       cadastroimobiliario.inscricaocadastralanterior as ci_inscricaocadastralanterior,
       cadastroimobiliario.quadra_inscricaocadastral as ci_quadra_inscricaocadastral,
       cadastroimobiliario.lote_inscricaocadastral as ci_lote_inscricaocadastral,
       cadastroimobiliario.distrito_inscricaocadastral as ci_distrito_inscricaocadastral,
       cadastroimobiliario.setor_inscricaocadastral as ci_setor_inscricaocadastral,
       cadastroimobiliario.unidade_inscricaocadastral as ci_unidade_inscricaocadastral,
       cadastroimobiliario.distrito_descr as ci_distrito_descr,
       cadastroimobiliario.setor_descr as ci_setor_descr,
       cadastroimobiliario.quadra_descr as ci_quadra_descr,
       cadastroimobiliario.lote_descr as ci_lote_descr,
       cadastroimobiliario.unidade_descr as ci_unidade_descr,
       cadastroimobiliario.imobiliaria as ci_imobiliaria,
       cadastroimobiliario.condominio as ci_condominio,
       cadastroimobiliario.loteamento as ci_loteamento,
       cadastroimobiliario.arealote as ci_arealote,
       cadastroimobiliario.profundidademedia as ci_profundidademedia,
       cadastroimobiliario.areatotalconstruida as ci_areatotalconstruida,
       cadastroimobiliario.matricula as ci_matricula,
       cadastroimobiliario.cartorio as ci_cartorio,
       cadastroimobiliario.datamatricula as ci_datamatricula,
       cadastroimobiliario.facequadra as ci_facequadra,
       cadastroimobiliario.areaunidadeconstruida as ci_areaunidadeconstruida,
       cadastroimobiliario.areautillote as ci_areautillote,
       cadastroimobiliario.areaprivativa as ci_areaprivativa,
       cadastroimobiliario.areacomum as ci_areacomum,
       cadastroimobiliario.complementolote as ci_complementolote,
       cadastroimobiliario.tipoimovel as ci_tipoimovel,
       cadastroimobiliario.tipolote as ci_tipolote,
       cadastroimobiliario.quadricula_inscricaocadastral as ci_quadricula_inscricao,
       cadastroimobiliario.numeroincra as ci_numeroincra,
       cadastroimobiliario.situacaodesapropriado as ci_situacaodesapropriado,
       cadastroimobiliario.quadricula_descri as ci_quadricula_descri,
       cadastroimobiliario.areatotalinscricao as ci_areatotalinscricao,
       cadastrogeral.pessoa                     as cg_pessoa                     ,
       cadastrogeral.logradouro                 as cg_logradouro                 ,
       cadastrogeral.numero                     as cg_numero                     ,
       cadastrogeral.englobado                  as cg_englobado                  ,
       cadastrogeral.complemento                as cg_complemento                ,
       cadastrogeral.suspensoemissao            as cg_suspensoemissao            ,
       cadastrogeral.cidade                     as cg_cidade                     ,
       cadastrogeral.bairro                     as cg_bairro                     ,
       cadastrogeral.correspondencialocal       as cg_correspondencialocal       ,
       cadastrogeral.datainclusao               as cg_datainclusao               ,
       cadastrogeral.dataalteracao              as cg_dataalteracao              ,
       cadastrogeral.cep                        as cg_cep                        ,
       cg.tipocadastroanterior       as cg_tipocadastroanterior       ,
       cg.cadastrogeralanterior      as cg_cadastrogeralanterior      ,
       cadastrogeral.enderecocorrespondencia    as cg_enderecocorrespondencia    ,
       cadastrogeral.numerocorrespondencia      as cg_numerocorrespondencia      ,
       cadastrogeral.complementocorrespondencia as cg_complementocorrespondencia ,
       cadastrogeral.cidadeufcorrespondencia    as cg_cidadeufcorrespondencia    ,
       cadastrogeral.cepcorrespondencia         as cg_cepcorrespondencia         ,
       cadastrogeral.bairrocorrespondencia      as cg_bairrocorrespondencia      ,
       cadastrogeral.enderecoentregacarneanual  as cg_enderecoentregacarneanual  ,
       cadastrogeral.ufcorrespondencia          as cg_ufcorrespondencia          ,
       (select case when count(1) > 0
                        then 1
                    else 0
                   end
        from tribimobiliariocaucao caucao
         left join tribimobiliariocaucao caucaoimob
           on caucaoimob.entidade = caucao.entidade
           and caucaoimob.caucao = caucao.caucao
        where caucao.tipocadastro = cadastroimobiliario.tipocadastro
          and caucao.cadastrogeral = cadastroimobiliario.cadastrogeral
          and caucaoimob.liberado = 'S') as sit_existecaucao,
       segmento.idkey as seg_id,
       segmento.sequencia as seg_sequencia,
       segmento.tiposegmento as seg_tiposegmento,
       segmento.areaconstruida as seg_areaconstruida,
       segmento.principal as seg_principal,
       segmento.areacoberta as seg_areacoberta,
       segmento.areadescoberta as seg_areadescoberta,
       segmento.idsegmentoimobiliario as seg_idsegmentoimobiliario,
       situacaoSegmento.idsituacaoSegmento as sitseg_idsituacaosegmento,
       situacaoSegmento.lancaimposto as sitseg_lancaimposto,
       situacaoSegmento.situacaoregular as sitseg_situacaoregular,
       tiposegmento.descricao as tiposeg_descricao,
       logradourotestada.idlogradourotestada     as lt_idlogradourotestada ,
       logradourotestada.distrito                as lt_distrito,
       logradourotestada.setor                   as lt_setor,
       logradourotestada.cidade                  as lt_cidade,
       logradourotestada.logradouro              as lt_logradouro,
       logradourotestada.quadra                  as lt_quadra,
       logradourotestada.facequadra              as lt_facequadra,
       logradourotestada.lado                    as lt_lado,
       logradourotestada.quadraoposta            as lt_quadraoposta,
       logradourotestada.quadricula              as lt_quadricula,
       logradourotestadaexercicio.exercicio           as lte_exercicio           ,
       logradourotestadaexercicio.largurarua          as lte_largurarua          ,
       logradourotestadaexercicio.valorterreno        as lte_valorterreno        ,
       logradourotestadaexercicio.valorterrenoitbi    as lte_valorterrenoitbi    ,
       logradourotestadaexercicio.valorterrenooutro   as lte_valorterrenooutro   ,
       (select count(1)
       from tribimobiliariosegmento seg
       left join TRIBSITUACAOSEGMENTOIMOB sit
              on seg.idsituacaosegmento = sit.idsituacaosegmento
       where seg.tipocadastro = cadastroimobiliario.tipocadastro
         and seg.cadastrogeral = cadastroimobiliario.cadastrogeral
         and coalesce(sit.lancaimposto, 'S') = 'S') as quantidadeConstrucoes,
       logradourotestada.idlogradourotestada,
       imobiliariotestadagenerica.id as itg_codigotestadagenerica,
       imobiliariotestadagenerica.cidade as itg_cidade,
       imobiliariotestadagenerica.logradouro as itg_logradouro,
       imobiliariotestadagenerica.tamanho as itg_tamanho,
       coalesce(imobiliariotestadagenerica.profundidade ,0) as itg_profundidade,
       imobiliariotestadagenerica.face as itg_face,
       coalesce(imobiliariotestadagenerica.valorm2,0) as itg_valorm2,
       imobiliariotestadagenerica.numero as itg_numero,
       tribsituacaoimobiliario.situacaoimobiliario as sit_situacaoimobiliario,
       tribsituacaoimobiliario.tiposituacaoimobiliario as sit_tiposituacaoimobiliario,
       coalesce(imobiliariotestada.tamanhotestada, 0) as it_testadaprincipal,
       coalesce((
                select sum(TribImobiliarioTestada.tamanhotestada)
                from tribimobiliariotestadamemoria TribImobiliarioTestada
                where TribImobiliarioTestada.cadastrogeral = cadastroimobiliario.cadastrogeral), 0) as it_somatestada,
       coalesce((
                select sum(lte.valorterreno)/count(it.*)
                from tribimobiliariotestadamemoria it
               	join triblogradourotestada lt on lt.idlogradourotestada = it.idlogradourotestada
               	join tribtestadaexerciciomemoria lte
               	  on lte.idlogradourotestada = lt.idlogradourotestada
               	 and lte.idmemoriacadastro = it.idmemoriacadastro
                where it.tipocadastro = cadastrogeral.tipocadastro
                and it.cadastrogeral = cadastrogeral.cadastrogeral
                and it.idmemoriacadastro = cadastrogeral.idmemoriacadastro
                and lte.exercicio = extract(year from now())
                and it.utilizaparacalculo  = 'S'), 0) as it_mediavalortestadas,
       coalesce((
                select sum(area)
                from tribimobiliarioareaverdemem tribimobiliarioareaverde
                where tribimobiliarioareaverde.tipocadastro = cadastrogeral.tipocadastro
                  and tribimobiliarioareaverde.cadastrogeral = cadastrogeral.cadastrogeral
                  and tribimobiliarioareaverde.idmemoriacadastro = cadastrogeral.idmemoriacadastro
                  and tribimobiliarioareaverde.consideraparacalculo = 'S'), 0) as av_area,
       coalesce((
                select max(tamanho)
                from tribimobiliariotestadagenerica
                where tribimobiliariotestadagenerica.tribcadastroimobiliario_idkey = tci.tribcadastrogeral_idkey), 0) as itg_tamanhomaiortestada,
       coalesce((
                 select min(tamanho)
                 from tribimobiliariotestadagenerica
                 where tribimobiliariotestadagenerica.tribcadastroimobiliario_idkey = tci.tribcadastrogeral_idkey), 0) as itg_tamanhomenortestada
  from tribcadastroimobiliariomemoria cadastroimobiliario
  join tribcadastrogeral cg
     on cg.cadastrogeral = cadastroimobiliario.cadastrogeral
    and cg.tipocadastro = cadastroimobiliario.tipocadastro
  join tribcadastrogeralmemoria cadastrogeral
     on cadastrogeral.cadastrogeral = cadastroimobiliario.cadastrogeral
    and cadastrogeral.tipocadastro = cadastroimobiliario.tipocadastro
    and cadastrogeral.idmemoriacadastro = cadastroimobiliario.idmemoriacadastro
  left join tribimobiliariosegmentomemoria segmento
    on cadastroimobiliario.tipocadastro = segmento.tipocadastro
   and cadastroimobiliario.cadastrogeral = segmento.cadastrogeral
   and cadastroimobiliario.idmemoriacadastro = segmento.idmemoriacadastro
  left join tribtiposegmento tiposegmento
    on segmento.tiposegmento = tiposegmento.tiposegmento
  left join TRIBSITUACAOSEGMENTOIMOB situacaoSegmento
    on segmento.idsituacaosegmento = situacaoSegmento.idsituacaosegmento
  left join tribimobiliariotestadamemoria imobiliariotestada
     on cadastroimobiliario.cadastrogeral = imobiliariotestada.cadastrogeral
    and cadastroimobiliario.tipocadastro = imobiliariotestada.tipocadastro
    and imobiliariotestada.principal = 'S'
  left join triblogradourotestada logradourotestada
    on imobiliariotestada.idlogradourotestada = logradourotestada.idlogradourotestada
   and logradourotestada.exclusaologica = 'N'
  left join tribtestadaexerciciomemoria logradourotestadaexercicio
    on logradourotestadaexercicio.idlogradourotestada = logradourotestada.idlogradourotestada
   and logradourotestadaexercicio.idmemoriacadastro = cadastroimobiliario.idmemoriacadastro
   and logradourotestadaexercicio.exercicio = :exercicio
   and logradourotestadaexercicio.principal = 'S'
  left join tribimobiliariotestadagenmem imobiliariotestadagenerica
    on cadastroimobiliario.tipocadastro = imobiliariotestadagenerica.tipocadastro
   and cadastroimobiliario.cadastrogeral = imobiliariotestadagenerica.cadastrogeral
   and cadastroimobiliario.idmemoriacadastro = imobiliariotestadagenerica.idmemoriacadastro
   and imobiliariotestadagenerica.principal = 'S'
  left join tribimobiliariosituacaomem tribimobiliariosituacao
    on tribimobiliariosituacao.tipocadastro = cadastroimobiliario.tipocadastro
   and tribimobiliariosituacao.cadastrogeral = cadastroimobiliario.cadastrogeral
   and tribimobiliariosituacao.idmemoriacadastro = imobiliariotestadagenerica.idmemoriacadastro
   and tribimobiliariosituacao.atual = 'S'
  left join tribsituacaoimobiliario tribsituacaoimobiliario
       on tribsituacaoimobiliario.situacaoimobiliario = tribimobiliariosituacao.situacaoimobiliario
  left join tribcadastroimobiliario tci
    on tci.tipocadastro = cg.tipocadastro
   and tci.cadastrogeral = cg.cadastrogeral
 where cadastrogeral.exclusaologica = 'N'
 and  (coalesce(situacaoSegmento.lancaimposto, 'S') = 'S' OR (cadastroimobiliario.tipoimovel = 'T'))
 and %s
